yakumo.nova.v2

Package yakumo :: Package nova :: Package v2 |
[hide private]
[frames] | no frames]

# Source Code for Package yakumo.nova.v2

     1  # Copyright 2014-2017 by Akira Yoshiyama <akirayoshiyama@gmail.com>.
     2  # All Rights Reserved.
     3  #
     4  #    Licensed under the Apache License, Version 2.0 (the "License"); you may
     5  #    not use this file except in compliance with the License. You may obtain
     6  #    a copy of the License at
     7  #
     8  #         http://www.apache.org/licenses/LICENSE-2.0
     9  #
    10  #    Unless required by applicable law or agreed to in writing, software
    11  #    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
    12  #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
    13  #    License for the specific language governing permissions and limitations
    14  #    under the License.
    15
    16  """
    17  Sub client class for Nova API v2
    18  """
    19
    20  from . import agent
    21  from . import aggregate
    22  from . import availability_zone
    23  from . import certificate
    24  from . import cloudpipe
    25  from . import fixed_ip
    26  from . import flavor
    27  from . import floating_ip
    28  from . import floating_ip_bulk
    29  from . import floating_ip_dns
    30  from . import hypervisor
    31  from . import image
    32  from . import key_pair
    33  from . import network
    34  from . import security_group
    35  from . import security_group_default_rule
    36  from . import server
    37  from . import server_group
    38  from . import service
    39  from . import quota_set
    40
    41
    42 -class Client(object):
    43
    44 -    def __init__(self, client, **kwargs):
    45          self.agent = agent.Manager(client, **kwargs)
    46          self.aggregate = aggregate.Manager(client, **kwargs)
    47          self.availability_zone = availability_zone.Manager(client, **kwargs)
    48          self.certificate = certificate.Manager(client, **kwargs)
    49          self.cloudpipe = cloudpipe.Manager(client, **kwargs)
    50          self.fixed_ip = fixed_ip.Manager(client, **kwargs)
    51          self.flavor = flavor.Manager(client, **kwargs)
    52          self.floating_ip = floating_ip.Manager(client, **kwargs)
    53          self.floating_ip_bulk = floating_ip_bulk.Manager(client, **kwargs)
    54          self.floating_ip_dns = floating_ip_dns.Manager(client, **kwargs)
    55          self.hypervisor = hypervisor.Manager(client, **kwargs)
    56          self.image = image.Manager(client, **kwargs)
    57          self.key_pair = key_pair.Manager(client, **kwargs)
    58          self.network = network.Manager(client, **kwargs)
    59          self.security_group = security_group.Manager(client, **kwargs)
    60          self.security_group_default_rule = \
    61              security_group_default_rule.Manager(client, **kwargs)
    62          self.server = server.Manager(client, **kwargs)
    63          self.server_group = server_group.Manager(client, **kwargs)
    64          self.service = service.Manager(client, **kwargs)
    65          self.quota_set = quota_set.Manager(client, **kwargs)
    66
    67          client.aggregate = self.aggregate
    68          client.availability_zone = self.availability_zone
    69          client.cloudpipe = self.cloudpipe
    70          client.fixed_ip = self.fixed_ip
    71          client.flavor = self.flavor
    72          client.floating_ip = self.floating_ip
    73          client.floating_ip_bulk = self.floating_ip_bulk
    74          client.floating_ip_dns = self.floating_ip_dns
    75          client.hypervisor = self.hypervisor
    76          client.image = self.image
    77          client.key_pair = self.key_pair
    78          client.network = self.network
    79          client.security_group = self.security_group
    80          client.security_group_default_rule = \
    81              self.security_group_default_rule
    82          client.server = self.server
    83          client.server_group = self.server_group
    84